from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Memory_ROM = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'XC18V01SO20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XC18V01SO20'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'xilinx/xc18v00proms.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_ROM.kicad_sym\nXC18V01SO20\n\n', 'pins':[
            Pin(num='1',name='D0',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='D7',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='CEO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='D5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='D3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='D1',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='TDO',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D2',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D4/CF',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='OE/RESET',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='D6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XCF08P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XCF08P'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'PROM FLASH', 'description':'', 'datasheet':'https://www.xilinx.com/support/documentation/data_sheets/ds123.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_ROM.kicad_sym\nXCF08P\n\nPROM FLASH', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='OE/RST',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='A6',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='B1',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='B6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='BUSY',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='C5',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='C6',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='CF',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='CEO',func=pin_types.OUTPUT,unit=1),
            Pin(num='D5',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='D6',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='E5',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='E6',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='F1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='REV-SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='G4',name='REV-SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='G5',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VCCJ',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='/EN-EXT-SEL',func=pin_types.INPUT,unit=1),
            Pin(num='H5',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='H6',name='D0',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Timer_PLL = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ADF4002BCPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4002BCPZ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'Analog Devices PFD', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4002.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4002BCPZ\n\nAnalog Devices PFD', 'pins':[
            Pin(num='1',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RFINB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RFINA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4002BRUZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4002BRUZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Analog Devices PFD', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4002.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4002BRUZ\n\nAnalog Devices PFD', 'pins':[
            Pin(num='1',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RFINB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RFINA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4158', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4158'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_CSP:LFCSP-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'fractional-N PLL', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4158.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4158\n\nfractional-N PLL', 'pins':[
            Pin(num='1',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SDGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='TXDATA',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SDVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SW1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='SW2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RFINB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RFINA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='REFIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4351', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4351'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'fractional-N PLL', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4351.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4351\n\nfractional-N PLL', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='RF_OUT_A+',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RF_OUT_A-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='RF_OUT_B+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RF_OUT_B-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='TEMP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VTUNE',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCOM',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PDB_RF',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SDGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='SDVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Vp',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CPout',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDCVF2505', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDCVF2505'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'pll clock driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cdcvf2505.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nCDCVF2505\n\npll clock driver', 'pins':[
            Pin(num='1',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='CLKOUT',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS2000-CP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS2000-CP'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'Clock Synthesizer Multiplier', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS2000-CP_F3.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nCS2000-CP\n\nClock Synthesizer Multiplier', 'pins':[
            Pin(num='1',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SDA/CDIN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLK_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AUX_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='CLK_IN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='XTI/REF_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AD0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SCL/CCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ICS525-01R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICS525-01R'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_3.9x9.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'keywords':'Configurable clock', 'description':'', 'datasheet':'https://www.idt.com/document/dst/525-01-02-datasheet', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nICS525-01R\n\nConfigurable clock', 'pins':[
            Pin(num='1',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V4',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='V6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='V7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='V8',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{PD}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='CLK',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='REF',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='R3',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1/ICLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='X2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342A-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342A-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342A-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344A-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344A-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344A-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345A-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345A-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345A-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4350'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'fractional-N PLL', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4350.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4350\n\nfractional-N PLL', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='RF_OUT_A+',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RF_OUT_A-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='RF_OUT_B+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RF_OUT_B-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='TEMP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VTUNE',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCOM',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PDB_RF',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SDGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='SDVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Vp',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CPout',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ICS525R-02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICS525R-02'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'keywords':'Configurable clock', 'description':'', 'datasheet':'https://www.idt.com/document/dst/525-01-02-datasheet', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nICS525R-02\n\nConfigurable clock', 'pins':[
            Pin(num='1',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V4',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='V6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='V7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='V8',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{PD}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='CLK',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='REF',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='R3',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1/ICLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='X2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342B-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342B-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342B-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342C-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342C-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342C-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342D-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342D-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342D-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344B-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344B-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344B-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344C-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344C-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344C-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344D-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344D-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344D-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345B-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345B-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345B-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345C-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345C-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345C-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345D-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345D-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345D-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Driver_Display = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'82720', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'82720'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Graphics Controller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\n82720\n\nGraphics Controller', 'pins':[
            Pin(num='1',name='2xWCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='DB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='DB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='DB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{DBIN}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='LPEN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AD0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AD1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AD4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AD5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AD6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='AD7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='HSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='AD8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='AD9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AD10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AD12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AD13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='AD15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='A16',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='A17',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VSYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BLANK',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='(ALE)~{RAS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DREQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{DACK}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RD}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843E'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843E\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AY0438X-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AY0438X-L'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-44'], 'footprint':'Package_LCC:PLCC-44', 'keywords':'driver display', 'description':'', 'datasheet':'http://www.farnell.com/datasheets/43336.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nAY0438X-L\n\ndriver display', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SEG_26',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='SEG_25',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SEG_24',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SEG_23',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SEG_22',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SEG_21',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SEG_20',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SEG_19',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SEG_18',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SEG_17',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='LOAD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SEG_16',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='SEG_15',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SEG_14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SEG_13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='SEG_12',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='SEG_11',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='SEG_10',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SEG_9',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SEG_32',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='SEG_8',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SEG_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='SEG_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BP',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='LCD0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='SEG_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='SEG_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DATA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DATA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SEG_31',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='SEG_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='SEG_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='SEG_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SEG_30',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='SEG_29',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SEG_28',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SEG_27',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AY0438X-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AY0438X-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'driver display', 'description':'', 'datasheet':'http://www.farnell.com/datasheets/43336.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nAY0438X-P\n\ndriver display', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SEG_25',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='SEG_24',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SEG_23',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SEG_22',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SEG_21',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SEG_20',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SEG_19',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SEG_18',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SEG_17',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SEG_16',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='LOAD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SEG_15',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='SEG_14',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SEG_13',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SEG_12',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='SEG_11',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='SEG_10',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='SEG_9',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SEG_8',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='SEG_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='SEG_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='SEG_32',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='BP',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='LCD0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='SEG_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='SEG_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DATA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='DATA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='SEG_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SEG_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SEG_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SEG_31',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SEG_30',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SEG_29',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SEG_28',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SEG_27',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SEG_26',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CR2013-MI2120', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CR2013-MI2120'}), 'ref_prefix':'U', 'fplist':['Display:CR2013-MI2120'], 'footprint':'Display:CR2013-MI2120', 'keywords':'driver display', 'description':'', 'datasheet':'http://pan.baidu.com/s/11Y990', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nCR2013-MI2120\n\ndriver display', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SD_CS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SD_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SD_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SD_SCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='FLASH_CD',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D/~{C}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='LED',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='MISO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XPT2046QF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XPT2046QF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm', 'keywords':'', 'description':'', 'datasheet':'http://www.xptek.cn/uploadfile/download/201707171401161883.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nXPT2046QF\n\n', 'pins':[
            Pin(num='1',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AUX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IOVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='YP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='YN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XPT2046TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XPT2046TS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, TSSOP-16', 'description':'', 'datasheet':'http://www.xptek.cn/uploadfile/download/201707171401161883.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nXPT2046TS\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, TSSOP-16', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IOVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='XP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='YP',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='XN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='YN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843E-2K5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843E-2K5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843E-2K5\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843EG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843EG4'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843EG4\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843IDBQRQ1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843IDBQRQ1'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +125 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843-q1.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843IDBQRQ1\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +125 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])